summaryrefslogtreecommitdiffstats
path: root/js/vendor/jquery/src/data.js
diff options
context:
space:
mode:
Diffstat (limited to 'js/vendor/jquery/src/data.js')
-rw-r--r--js/vendor/jquery/src/data.js89
1 files changed, 49 insertions, 40 deletions
diff --git a/js/vendor/jquery/src/data.js b/js/vendor/jquery/src/data.js
index f9af9ae67..b626fda45 100644
--- a/js/vendor/jquery/src/data.js
+++ b/js/vendor/jquery/src/data.js
@@ -1,10 +1,9 @@
-define([
+define( [
"./core",
- "./var/rnotwhite",
"./core/access",
- "./data/var/data_priv",
- "./data/var/data_user"
-], function( jQuery, rnotwhite, access, data_priv, data_user ) {
+ "./data/var/dataPriv",
+ "./data/var/dataUser"
+], function( jQuery, access, dataPriv, dataUser ) {
// Implementation Summary
//
@@ -17,7 +16,7 @@ define([
// 6. Provide a clear path for implementation upgrade to WeakMap in 2014
var rbrace = /^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,
- rmultiDash = /([A-Z])/g;
+ rmultiDash = /[A-Z]/g;
function dataAttr( elem, key, data ) {
var name;
@@ -25,7 +24,7 @@ function dataAttr( elem, key, data ) {
// If nothing was found internally, try to fetch any
// data from the HTML5 data-* attribute
if ( data === undefined && elem.nodeType === 1 ) {
- name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();
+ name = "data-" + key.replace( rmultiDash, "-$&" ).toLowerCase();
data = elem.getAttribute( name );
if ( typeof data === "string" ) {
@@ -33,14 +32,15 @@ function dataAttr( elem, key, data ) {
data = data === "true" ? true :
data === "false" ? false :
data === "null" ? null :
+
// Only convert to a number if it doesn't change the string
+data + "" === data ? +data :
rbrace.test( data ) ? jQuery.parseJSON( data ) :
data;
- } catch( e ) {}
+ } catch ( e ) {}
// Make sure we set the data so it isn't changed later
- data_user.set( elem, key, data );
+ dataUser.set( elem, key, data );
} else {
data = undefined;
}
@@ -48,31 +48,31 @@ function dataAttr( elem, key, data ) {
return data;
}
-jQuery.extend({
+jQuery.extend( {
hasData: function( elem ) {
- return data_user.hasData( elem ) || data_priv.hasData( elem );
+ return dataUser.hasData( elem ) || dataPriv.hasData( elem );
},
data: function( elem, name, data ) {
- return data_user.access( elem, name, data );
+ return dataUser.access( elem, name, data );
},
removeData: function( elem, name ) {
- data_user.remove( elem, name );
+ dataUser.remove( elem, name );
},
// TODO: Now that all calls to _data and _removeData have been replaced
// with direct calls to data_priv methods, these can be deprecated.
_data: function( elem, name, data ) {
- return data_priv.access( elem, name, data );
+ return dataPriv.access( elem, name, data );
},
_removeData: function( elem, name ) {
- data_priv.remove( elem, name );
+ dataPriv.remove( elem, name );
}
-});
+} );
-jQuery.fn.extend({
+jQuery.fn.extend( {
data: function( key, value ) {
var i, name, data,
elem = this[ 0 ],
@@ -81,9 +81,9 @@ jQuery.fn.extend({
// Gets all values
if ( key === undefined ) {
if ( this.length ) {
- data = data_user.get( elem );
+ data = dataUser.get( elem );
- if ( elem.nodeType === 1 && !data_priv.get( elem, "hasDataAttrs" ) ) {
+ if ( elem.nodeType === 1 && !dataPriv.get( elem, "hasDataAttrs" ) ) {
i = attrs.length;
while ( i-- ) {
@@ -92,12 +92,12 @@ jQuery.fn.extend({
if ( attrs[ i ] ) {
name = attrs[ i ].name;
if ( name.indexOf( "data-" ) === 0 ) {
- name = jQuery.camelCase( name.slice(5) );
+ name = jQuery.camelCase( name.slice( 5 ) );
dataAttr( elem, name, data[ name ] );
}
}
}
- data_priv.set( elem, "hasDataAttrs", true );
+ dataPriv.set( elem, "hasDataAttrs", true );
}
}
@@ -106,14 +106,13 @@ jQuery.fn.extend({
// Sets multiple values
if ( typeof key === "object" ) {
- return this.each(function() {
- data_user.set( this, key );
- });
+ return this.each( function() {
+ dataUser.set( this, key );
+ } );
}
return access( this, function( value ) {
- var data,
- camelKey = jQuery.camelCase( key );
+ var data, camelKey;
// The calling jQuery object (element matches) is not empty
// (and therefore has an element appears at this[ 0 ]) and the
@@ -121,16 +120,24 @@ jQuery.fn.extend({
// will result in `undefined` for elem = this[ 0 ] which will
// throw an exception if an attempt to read a data cache is made.
if ( elem && value === undefined ) {
+
// Attempt to get data from the cache
// with the key as-is
- data = data_user.get( elem, key );
+ data = dataUser.get( elem, key ) ||
+
+ // Try to find dashed key if it exists (gh-2779)
+ // This is for 2.2.x only
+ dataUser.get( elem, key.replace( rmultiDash, "-$&" ).toLowerCase() );
+
if ( data !== undefined ) {
return data;
}
+ camelKey = jQuery.camelCase( key );
+
// Attempt to get data from the cache
// with the key camelized
- data = data_user.get( elem, camelKey );
+ data = dataUser.get( elem, camelKey );
if ( data !== undefined ) {
return data;
}
@@ -147,32 +154,34 @@ jQuery.fn.extend({
}
// Set the data...
- this.each(function() {
+ camelKey = jQuery.camelCase( key );
+ this.each( function() {
+
// First, attempt to store a copy or reference of any
// data that might've been store with a camelCased key.
- var data = data_user.get( this, camelKey );
+ var data = dataUser.get( this, camelKey );
// For HTML5 data-* attribute interop, we have to
// store property names with dashes in a camelCase form.
// This might not apply to all properties...*
- data_user.set( this, camelKey, value );
+ dataUser.set( this, camelKey, value );
// *... In the case of properties that might _actually_
// have dashes, we need to also store a copy of that
// unchanged property.
- if ( key.indexOf("-") !== -1 && data !== undefined ) {
- data_user.set( this, key, value );
+ if ( key.indexOf( "-" ) > -1 && data !== undefined ) {
+ dataUser.set( this, key, value );
}
- });
+ } );
}, null, value, arguments.length > 1, null, true );
},
removeData: function( key ) {
- return this.each(function() {
- data_user.remove( this, key );
- });
+ return this.each( function() {
+ dataUser.remove( this, key );
+ } );
}
-});
+} );
return jQuery;
-});
+} );
@@ -48,31 +48,31 @@ function dataAttr( elem, key, data ) {
},
// TODO: Now that all calls to _data and _removeData have been replaced
- // with direct calls to data_priv methods, these can be deprecated.
+ // with direct calls to dataPriv methods, these can be deprecated.
_data: function( elem, name, data ) {